@@ -1,8 +1,8 @@
 ;;; ac-dcd.el --- Auto Completion source for dcd for GNU Emacs
 
 ;; Author:  <atila.neves@gmail.com>
-;; Package-Version: 0.6
-;; Package-Revision: V0.6-0-gd378d33c7bed
+;; Package-Version: 20250925.946
+;; Package-Revision: b95dfc61b9f2
 ;; Package-Requires: ((auto-complete "1.3.1") (flycheck-dmd-dub "0.7"))
 ;; Keywords: languages
 ;; URL: http://github.com/atilaneves/ac-dcd
@@ -96,7 +96,7 @@ If you want to restart server, use `ac-dcd-init-server' instead."
 
 (defsubst ac-dcd-start-server ()
   "Start dcd-server."
-  (let ((buf (get-buffer-create "*dcd-server*")))
+  (let ((buf (get-buffer-create " *dcd-server*")))
     (with-current-buffer buf (apply 'start-process "dcd-server" (current-buffer)
                                             ac-dcd-server-executable
                                             "-p"
@@ -537,8 +537,8 @@ dcd-client outputs candidates that begin with \"this\" when completing struct co
     (with-current-buffer buf
       (erase-buffer)
 
-          (apply 'call-process-region (point-min) (point-max)
-                         ac-dcd-executable nil buf nil (cons "--tcp" args))
+      (apply 'call-process-region (point-min) (point-max)
+             ac-dcd-executable nil buf nil (cons "--tcp" args))
       (when (or
              (string= (buffer-string) "")
              (string= (buffer-string) "\n\n\n")             ;when symbol has no doc
@@ -648,36 +648,39 @@ output is just like following.\n
 (defun ac-dcd-find-imports-dub ()
   "Extract import flags from \"dub describe\" output."
   (let* ((basedir (fldd--get-project-dir)))
-        (if basedir
-                (mapcar (lambda (x) (concat "-I" x)) (fldd--get-dub-package-dirs))
-          nil)))
+    (if basedir
+        (mapcar (lambda (x) (concat "-I" x)) (fldd--get-dub-package-dirs))
+      nil)))
 
 (defun ac-dcd-find-imports-std ()
-  "Extract import flags from dmd.conf file."
-  (require 'cl)
-  (let ((dmd-conf-filename
-         (find-if 'file-exists-p
-                  (list
-                   ;; TODO: the first directory to look into should be dmd's current
-                   ;; working dir
-                   (concat (getenv "HOME") "/dmd.conf")
-                   (concat (ac-dcd-parent-directory (executable-find "dmd")) "dmd.conf")
-                   "/usr/local/etc/dmd.conf"
-                   "/etc/dmd.conf"))))
-
-    ;; TODO: this extracting procedure is pretty rough, it just searches for
-    ;; the first occurrence of the DFLAGS
-    (save-window-excursion
-      (with-temp-buffer
-        (find-file dmd-conf-filename)
-        (goto-char (point-min))
-        (search-forward "\nDFLAGS")
-        (skip-chars-forward " =")
-        (let ((flags-list (split-string (buffer-substring-no-properties
-                                         (point) (line-end-position)))))
-          (remove-if-not '(lambda (s)
-                            (string-prefix-p "-I" s))
-                         flags-list))))))
+  "Extract import flags from a D compiler dmd.conf file, including ~/dlang installs."
+  (require 'cl-lib)
+  (let* ((dmd-bin (executable-find "dmd"))
+         (dmd-parent (and dmd-bin (ac-dcd-parent-directory dmd-bin)))
+         (dlang-dir (expand-file-name "~/dlang"))
+         (dlang-confs (when (file-directory-p dlang-dir)
+                        (ignore-errors
+                          (directory-files-recursively dlang-dir "^dmd\\.conf$"))))
+         (candidates
+          (append
+           (delq nil
+                 (list
+                  (expand-file-name "dmd.conf" (getenv "HOME"))
+                  (when dmd-parent (expand-file-name "dmd.conf" dmd-parent))
+                  "/usr/local/etc/dmd.conf"
+                  "/etc/dmd.conf"))
+           dlang-confs))
+         (dmd-conf-filename (cl-find-if #'file-exists-p candidates)))
+    (when dmd-conf-filename
+      (save-window-excursion
+        (with-temp-buffer
+          (insert-file-contents dmd-conf-filename)
+          (goto-char (point-min))
+          (when (re-search-forward "^[ \t]*DFLAGS[ \t]*=" nil t)
+            (let* ((flags (buffer-substring-no-properties (point) (line-end-position)))
+                   (flags-list (split-string flags "[ \t]+" t)))
+              (cl-remove-if-not (lambda (s) (string-prefix-p "-I" s))
+                                flags-list))))))))
 
 (defun ac-dcd--find-all-project-imports ()
   "Find all project imports, including std packages and dub dependencies."
